@@ -21,10 +21,10 @@ Description:
 
 CVS Information:
 
-    $Source: /home/globdev/CVS/globus-packages/gram_client_tools/source/globusrun.c,v $
-    $Date: 2012/05/21 17:42:35 $
-    $Revision: 1.38.6.2 $
-    $Author: bester $
+    $Source$
+    $Date$
+    $Revision$
+    $Author$
 ******************************************************************************/
 
 /******************************************************************************
@@ -291,38 +291,6 @@ test_job_id( char *    value,
     return res;
 }
 
-int
-test_hostname( char *   value,
-	       void *   ignored,
-	       char **  errmsg )
-{
-    struct hostent *   hostent;
-    struct hostent     result;
-    char               buf[1024];
-    int                rc;
-
-    hostent = globus_libc_gethostbyname_r( (char *) value,
-					   &result,
-					   buf,
-					   1024,
-					   &rc     );
-    if (hostent == NULL)
-	*errmsg = globus_libc_strdup("cannot resolve hostname");
-    return rc;
-}
-
-int
-test_integer( char *   value,
-	      void *   ignored,
-	      char **  errmsg )
-{
-    int  res = (atoi(value) <= 0);
-    if (res)
-	*errmsg = globus_libc_strdup("argument is not a positive integer");
-    return res;
-}
-
-
 enum { arg_q = 1, arg_o, arg_s, arg_w, arg_n, arg_b,
 	     arg_p, arg_d, arg_a,
 	     arg_r, arg_f, arg_k, arg_y, arg_status,
@@ -640,31 +608,42 @@ main(int argc, char* argv[])
     {
 	int fd;
 
-	fd = globus_libc_open (request_file, O_RDONLY, 0600);
+	fd = open(request_file, O_RDONLY);
 	if ( fd >= 0 )
 	{
 	    int i;
 	    char c;
+            struct stat stbuf;
 	    globus_off_t len = 0;
 
-	    len = globus_libc_lseek(fd, 0, SEEK_END);
-	    globus_libc_lseek(fd, 0, SEEK_SET);
+            if ((fstat(fd, &stbuf) == 0) && (S_ISREG(stbuf.st_mode)))
+            {
+                len = stbuf.st_size;
+                request_string = malloc(sizeof (char) * (len + 1));
+                if (request_string)
+                {
+                    i=0;
 
-	    request_string = (char *) malloc (sizeof (char)
-					      * (len + 1));
-	    i=0;
+                    while ( (i<len)  && read(fd, &c, 1) > 0)
+                    {
+                        request_string[i] = c;
+                        i++;
+                    }
+                    request_string[i] = '\0';
 
-	    while ( (i<len)  && read(fd, &c, 1) > 0)
-	    {
-		request_string[i] = c;
-		i++;
-	    }
-	    request_string[i] = '\0';
-
-	    free (request_file);
-	    request_file = NULL;
-
-	    globus_libc_close (fd);
+                }
+                else
+                {
+                    globusrun_l_args_error_fmt("out of memory: %s",request_file);
+                }
+            }
+            else
+            {
+                globusrun_l_args_error_fmt("not a regular file: %s", request_file);
+            }
+            free (request_file);
+            request_file = NULL;
+            close (fd);
 	}
 	else
 	{
